import koji
import fedmsg
import fedmsg.encoding

from . import utils, config
from . import JobTrigger

ITEM_TYPE = 'koji_build'

class KojiBuildCompletedJobTrigger(JobTrigger):
    topic = "org.fedoraproject.prod.buildsys.build.state.change"
    jsonify = False
    config_key = 'taskotron.kojibuildcompletedjobtrigger.enabled'

    def __init__(self, *args, **kw):
        super(KojiBuildCompletedJobTrigger, self).__init__(*args, **kw)

    def consume(self, message):
        usable_message = fedmsg.encoding.loads(message.body)

        release = usable_message['msg']['release']
        state = usable_message['msg']['new']

        # we only look for successfuly completed builds
        if state != koji.BUILD_STATES['COMPLETE']:
            return

        # do not schledule jobs for blacklisted releases
        if release.endswith(tuple(config.blacklist_releases)):
            return

        name = usable_message['msg']['name']
        version = usable_message['msg']['version']
        buildid = usable_message['msg']['build_id']

        envr = "%s-%s-%s" % (name, version, release)

        arches = utils.get_arches(buildid=buildid)

        self.trigger_tasks(envr, ITEM_TYPE, config.koji_build_completed_tasks, arches)
